@@ -17,7 +17,10 @@ You should have received a copy of the GNU General Public License
 along with qdatamatatrix.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-__version__ = '0.1.24'
+__version__ = '0.1.25'
 
+import os
 from datamatrix.py3compat import *
-from qdatamatrix._qdatamatrix import QDataMatrix
+# In case we only want to get the version
+if os.environ.get('NO_QTPY', '0') != '1':
+    from qdatamatrix._qdatamatrix import QDataMatrix
